pub enum FilterRule {
Tautology,
Contradiction,
Conjunction(Vec<FilterRule>),
Disjunction(Vec<FilterRule>),
Negation(Box<FilterRule>),
Severity(Comparator, Severity),
Confidence(Comparator, Confidence),
Key(ErrorKey),
File(Pattern),
Text(String),
}Variants
Tautology
Always true.
Contradiction
Always false.
Conjunction(Vec<FilterRule>)
Configured by the AND-key. The top-level rule is always a conjunction. Reports must match all enclosed rules to match the conjunction.
Disjunction(Vec<FilterRule>)
Configured by the OR-key. Reports must match at least one of the enclosed rules to match the disjunction.
Negation(Box<FilterRule>)
Configured by the NOT-key. Reports must not match the enclosed rule to match the negation.
Severity(Comparator, Severity)
Reports must be within the given Severity range to match the rule.
The condition is built like severity >= error in the filter trigger.
Confidence(Comparator, Confidence)
Reports must be within the given Confidence range to match the rule.
The condition is built like confidence > weak in the filter trigger.
Key(ErrorKey)
The report’s ErrorKey must be the listed key for the report to match the rule.
File(Pattern)
The report’s pointers must contain the given file for the report to match the rule.
Text(String)
The report’s msg must contain the given text for the report to match the rule.
Implementations
Sourceimpl FilterRule
impl FilterRule
fn apply( &self, report: &LogReportMetadata, pointers: &LogReportPointers, ) -> bool
pub fn file_from_token(token: &Token) -> Option<FilterRule>